Crate securepass
source ·Expand description
This crate provides functionality to generate and balance passwords with various options and strengths.
Structs
- Structure representing the options for password generation.
- Structure representing the specification of a password.
Enums
- Enum representing the strength of a password.
Functions
- Balances a password to ensure it meets the specified criteria.
- Calculates the entropy of a password.
- Checks the strength of a password.
- Generates a random password from the given character set and length.